==> ubicoders-vrobots-2.0.14.tar.gz: ubicoders-vrobots-2.0.14/src/ubicoders_vrobots/vrobots_graph_tools/data_visualization.py <==
from collections import deque
from dash import dcc, html, Dash
from dash.dependencies import Input, Output
import plotly.graph_objects as go
from plotly.subplots import make_subplots
import logging, sys

# Set logging level to WARNING to suppress other messages
log = logging.getLogger("werkzeug")
log.disabled = True
cli = sys.modules["flask.cli"]
cli.show_server_banner = lambda *x: None


class DataVisualizationApp:
    def __init__(self, title="Real-Time Data Visualization", y_label="", interval=100):
        self.app = Dash(__name__)
        self.title = title
        self.y_label = y_label
        self.interval = interval
        self.data_queue = deque(maxlen=250)
        self._setup_layout()
        self._setup_callbacks()

    def _setup_layout(self):
        """Define the app layout."""
        self.app.layout = html.Div(
            [
                html.H1(self.title),
                dcc.Graph(id="live-graph"),
                dcc.Interval(
                    id="interval-component", interval=self.interval, n_intervals=0
                ),
            ]
        )

    def _setup_callbacks(self):
        """Define the callback for updating the graph."""

        @self.app.callback(
            Output("live-graph", "figure"), Input("interval-component", "n_intervals")
        )
        def update_graph_live(n):
            times = list(range(len(self.data_queue)))
            x_data = [item[0] for item in self.data_queue]
            y_data = [item[1] for item in self.data_queue]
            z_data = [item[2] for item in self.data_queue]

            fig = make_subplots(
                rows=3,
                cols=1,
                shared_xaxes=True,
                subplot_titles=(
                    f"{self.y_label} - X",
                    f"{self.y_label} - Y",
                    f"{self.y_label} - Z",
                ),
            )

            fig.add_trace(
                go.Scatter(
                    x=times, y=x_data, mode="lines+markers", name=f"{self.y_label} Axis"
                ),
                row=1,
                col=1,
            )
            fig.add_trace(
                go.Scatter(
                    x=times, y=y_data, mode="lines+markers", name=f"{self.y_label} Axis"
                ),
                row=2,
                col=1,
            )
            fig.add_trace(
                go.Scatter(
                    x=times, y=z_data, mode="lines+markers", name=f"{self.y_label} Axis"
                ),
                row=3,
                col=1,
            )

            fig.update_layout(height=800, title_text=self.title, showlegend=False)
            fig.update_xaxes(title_text="Time", row=3, col=1)
            # fig.update_yaxes(title_text=f"{self.y_label} Value", row=1, col=1)
            # fig.update_yaxes(title_text=f"{self.y_label} Value", row=2, col=1)
            # fig.update_yaxes(title_text=f"{self.y_label} Value", row=3, col=1)

            return fig

    def clear_data(
        self,
    ):
        self.data_queue.clear()

    def append_data(self, data_point):
        """Append data to the shared queue."""
        self.data_queue.append(data_point)

    def run(self, debug=True):
        """Run the Dash server."""
        print(
            "\033[92m" + "Plot server is running on http://localhost:8050/" + "\033[0m"
        )

        self.app.run_server(debug=debug, use_reloader=False)

==> ubicoders-vrobots-2.0.17.tar.gz: ubicoders-vrobots-2.0.17/src/ubicoders_vrobots/vrobots_graph_tools/data_visualization.py <==
from collections import deque
from dash import dcc, html, Dash
from dash.dependencies import Input, Output
import plotly.graph_objects as go
from plotly.subplots import make_subplots
import logging, sys

log = logging.getLogger("werkzeug")
log.disabled = True  # Disables all werkzeug logs
cli = sys.modules["flask.cli"]
cli.show_server_banner = lambda *x: None


class DataVisualizationApp:
    def __init__(self, title="Real-Time Data Visualization", y_label="", interval=100):
        self.app = Dash(__name__)
        self.title = title
        self.y_label = y_label
        self.interval = interval
        self.data_queue = deque(maxlen=250)
        self._setup_layout()
        self._setup_callbacks()

    def _setup_layout(self):
        """Define the app layout."""
        self.app.layout = html.Div(
            [
                html.H1(self.title),
                dcc.Graph(id="live-graph"),
                dcc.Interval(
                    id="interval-component", interval=self.interval, n_intervals=0
                ),
            ]
        )

    def _setup_callbacks(self):
        """Define the callback for updating the graph."""

        @self.app.callback(
            Output("live-graph", "figure"), Input("interval-component", "n_intervals")
        )
        def update_graph_live(n):
            times = [item[0] for item in self.data_queue]
            x_data = [item[1] for item in self.data_queue]
            y_data = [item[2] for item in self.data_queue]
            z_data = [item[3] for item in self.data_queue]

            fig = make_subplots(
                rows=3,
                cols=1,
                shared_xaxes=False,
                subplot_titles=(
                    f"{self.y_label} - X",
                    f"{self.y_label} - Y",
                    f"{self.y_label} - Z",
                ),
            )

            fig.add_trace(
                go.Scatter(
                    x=times, y=x_data, mode="lines+markers", name=f"{self.y_label} Axis"
                ),
                row=1,
                col=1,
            )
            fig.add_trace(
                go.Scatter(
                    x=times, y=y_data, mode="lines+markers", name=f"{self.y_label} Axis"
                ),
                row=2,
                col=1,
            )
            fig.add_trace(
                go.Scatter(
                    x=times, y=z_data, mode="lines+markers", name=f"{self.y_label} Axis"
                ),
                row=3,
                col=1,
            )

            fig.update_layout(height=800, title_text=self.title, showlegend=False)
            fig.update_xaxes(title_text="Time", row=3, col=1)

            return fig

    def clear_data(
        self,
    ):
        self.data_queue.clear()

    def append_data(self, data_point):
        """Append data to the shared queue."""
        self.data_queue.append(data_point)

    def run(self, debug=True):
        """Run the Dash server."""
        print(
            "\033[92m" + "Plot server is running on http://localhost:8050/" + "\033[0m"
        )
        self.app.run_server(debug=debug, use_reloader=False)
